@@ -15,16 +15,20 @@
 #' variable. You can use [long_to_periods()] to transform your data in such
 #' format. Beginning and ending of each tile is determined by `start` and
 #' `stop` arguments.
-#' @param data A data frame, or a data frame extension (e.g. a tibble).
-#' @param id <[`tidy-select`][dplyr::dplyr_tidy_select ]>
+#'
+#' For survey design objects, weights are not taken into account. Each
+#' individual trajectory as the same height.
+#' @param data A data frame, a data frame extension (e.g. a tibble), or a
+#' survey design object.
+#' @param id <[`tidy-select`][dplyr::dplyr_tidy_select ]>\cr
 #' Column containing individual ids.
-#' @param time <[`tidy-select`][dplyr::dplyr_tidy_select ]>
+#' @param time <[`tidy-select`][dplyr::dplyr_tidy_select ]>\cr
 #' Time variable.
-#' @param fill <[`tidy-select`][dplyr::dplyr_tidy_select ]>
+#' @param fill <[`tidy-select`][dplyr::dplyr_tidy_select ]>\cr
 #' Variable mapped to `fill` aesthetic.
-#' @param by <[`tidy-select`][dplyr::dplyr_tidy_select ]>
+#' @param by <[`tidy-select`][dplyr::dplyr_tidy_select ]>\cr
 #' Optional variables to group by.
-#' @param sort_by <[`tidy-select`][dplyr::dplyr_tidy_select ]>
+#' @param sort_by <[`tidy-select`][dplyr::dplyr_tidy_select ]>\cr
 #' Optional variables to sort trajectories.
 #' @param nudge_x Optional amount of horizontal distance to move.
 #' @param hide_y_labels Hide y labels? If `NULL`, hide them when more than 20
@@ -69,6 +73,10 @@ plot_trajectories <- function(
   facet_labeller = ggplot2::label_wrap_gen(width = 50, multi_line = TRUE),
   ...
 ) {
+  if (inherits(data, "survey.design")) {
+    data <- data$variables
+  }
+
   # selection and checks
   idv <-
     tidyselect::eval_select(
@@ -186,6 +194,10 @@ plot_periods <- function(
   facet_labeller = ggplot2::label_wrap_gen(width = 50, multi_line = TRUE),
   ...
 ) {
+  if (inherits(data, "survey.design")) {
+    data <- data$variables
+  }
+
   startv <-
     tidyselect::eval_select(
       rlang::enquo(start),
